@@ -2,7 +2,7 @@ from ocgis import env
 from ocgis.api.interpreter import OcgInterpreter
 from ocgis.api.parms.base import AbstractParameter
 from ocgis.api.parms.definition import *
-from ocgis.api.subset import SubsetOperation
+from ocgis.api.subset import OperationsEngine
 from ocgis.conv.base import get_converter
 from ocgis.conv.meta import MetaOCGISConverter
 from ocgis.interface.base.crs import CFRotatedPole, WGS84
@@ -109,6 +109,14 @@ class OcgOperations(object):
      individual columns in tabular output formats (i.e. ``'csv'``). If ``True``, all variable values will be collected
      under a single value column.
     :param dict output_format_options: A dictionary of output-specific format options.
+    :param str spatial_wrapping: If ``"wrap"`` or ``"unwrap"``, wrap or unwrap the spatial coordinates if the associated
+     coordinate system is a wrappable coordinate system like spherical latitude/longitude.
+    :param bool spatial_reorder: If ``True``, reorder wrapped coordinates such that the longitude values are in
+     ascending order. Reordering assumes the first row of longitude coordinates are representative of the other
+     longitude coordinate rows. Bounds and corners will be removed in the event of a reorder. Only applies to spherical
+     coordinate systems.
+    :param bool optimized_bbox_subset: If ``True``, only perform the bounding box subset ignoring other subsetting
+     procedures such as spatial operations on geometry objects using a spatial index.
     """
 
     def __init__(self, dataset=None, spatial_operation='intersects', geom=None, geom_select_sql_where=None,
@@ -119,7 +127,8 @@ class OcgOperations(object):
                  search_radius_mult=2.0, output_crs=None, interpolate_spatial_bounds=False, add_auxiliary_files=True,
                  optimizations=None, callback=None, time_range=None, time_region=None, time_subset_func=None,
                  level_range=None, conform_units_to=None, select_nearest=False, regrid_destination=None,
-                 regrid_options=None, melted=False, output_format_options=None):
+                 regrid_options=None, melted=False, output_format_options=None, spatial_wrapping=None,
+                 spatial_reorder=False, optimized_bbox_subset=False):
 
         # Tells "__setattr__" to not perform global validation until all values are initially set.
         self._is_init = True
@@ -155,6 +164,7 @@ class OcgOperations(object):
         self.interpolate_spatial_bounds = InterpolateSpatialBounds(interpolate_spatial_bounds)
         self.add_auxiliary_files = AddAuxiliaryFiles(add_auxiliary_files)
         self.optimizations = Optimizations(optimizations)
+        self.optimized_bbox_subset = OptimizedBoundingBoxSubset(optimized_bbox_subset)
         self.callback = Callback(callback)
         self.time_range = TimeRange(time_range)
         self.time_region = TimeRegion(time_region)
@@ -166,6 +176,8 @@ class OcgOperations(object):
         self.regrid_options = RegridOptions(regrid_options)
         self.melted = Melted(init_value=env.MELTED or melted, dataset=self._get_object_('dataset'),
                              output_format=self._get_object_('output_format'))
+        self.spatial_wrapping = SpatialWrapping(spatial_wrapping)
+        self.spatial_reorder = SpatialReorder(spatial_reorder)
 
         # These values are left in to perhaps be added back in at a later date.
         self.output_grouping = None
@@ -254,7 +266,7 @@ class OcgOperations(object):
             return ret
 
         ops_size = deepcopy(self)
-        subset = SubsetOperation(ops_size, request_base_size_only=True)
+        subset = OperationsEngine(ops_size, request_base_size_only=True)
         ret = dict(variables={})
         for coll in subset:
             for row in coll.get_iter_melted():
@@ -413,4 +425,4 @@ class OcgOperations(object):
                     _raise_(msg, obj=CalcGrouping)
             else:
                 for c in self.calc:
-                    c['ref'].validate(self)
\ No newline at end of file
+                    c['ref'].validate(self)
