@@ -23,6 +23,7 @@ from ocgis.api.parms.definition_helpers import MetadataAttributes
 from ocgis.api.request.base import RequestDataset, RequestDatasetCollection
 from ocgis.calc.eval_function import EvalFunction, MultivariateEvalFunction
 from ocgis.calc.library import register
+from ocgis.constants import WrapAction
 from ocgis.conv.base import AbstractTabularConverter, get_converter, get_converter_map
 from ocgis.exc import DefinitionValidationError, NoDimensionedVariablesFound
 from ocgis.interface.base.crs import CoordinateReferenceSystem, CFWGS84
@@ -643,7 +644,7 @@ class Geom(base.AbstractParameter):
                     minx, miny, maxx, maxy = value
                     geom = Polygon(((minx, miny), (minx, maxy), (maxx, maxy), (maxx, miny)))
                 if not geom.is_valid:
-                    raise (DefinitionValidationError(self, 'Parsed geometry is not valid.'))
+                    raise DefinitionValidationError(self, 'Parsed geometry is not valid.')
                 ret = [{'geom': geom, 'properties': {self._ugid_key: 1}}]
                 ret = SpatialDimension.from_records(ret, crs=CFWGS84(), uid=self.geom_uid)
                 self._bounds = geom.bounds
@@ -669,6 +670,11 @@ class Geom(base.AbstractParameter):
         return ret
 
     def parse_string(self, value):
+        if isinstance(value, basestring):
+            if os.path.isdir(value):
+                exc = DefinitionValidationError(self, 'The provided path is a directory.')
+                ocgis_lh(exc=exc, logger='definition')
+
         elements = value.split('|')
         try:
             elements = [float(e) for e in elements]
@@ -911,6 +917,13 @@ class Optimizations(base.AbstractParameter):
             raise DefinitionValidationError(self, msg)
 
 
+class OptimizedBoundingBoxSubset(base.BooleanParameter):
+    name = 'optimized_bbox_subset'
+    default = False
+    meta_true = 'Optimized bounding box subset used.'
+    meta_false = 'Standard subsetting procedure used.'
+
+
 class OutputCRS(base.AbstractParameter):
     input_types = [CoordinateReferenceSystem]
     name = 'output_crs'
@@ -1157,7 +1170,41 @@ class SpatialOperation(base.StringOptionParameter):
             ret = 'Geometries touching AND overlapping returned.'
         else:
             ret = 'A full geometric intersection occurred. Where geometries overlapped, a new geometry was created.'
-        return (ret)
+        return ret
+
+
+class SpatialReorder(base.BooleanParameter):
+    name = 'spatial_reorder'
+    default = False
+    meta_true = 'Reorder data and coordinate arrays to have ascending longitudinal coordinates.'
+    meta_false = 'Do not reorder data and coordinate arrays to have ascending longitudinal coordinates.'
+
+
+class SpatialWrapping(base.StringOptionParameter):
+    name = 'spatial_wrapping'
+    default = None
+    nullable = True
+    valid = ('wrap', 'unwrap', None)
+    _enum_mapping = {'wrap': WrapAction.WRAP, 'unwrap': WrapAction.UNWRAP}
+
+    @property
+    def as_enum(self):
+        if self.value is None:
+            ret = None
+        else:
+            ret = self._enum_mapping[self.value]
+        return ret
+
+    @classmethod
+    def iter_possible(cls):
+        for v in cls.valid:
+            yield v
+
+    def _get_meta_(self):
+        msgs = {'wrap': 'Wrap data to -180 to 180 degree spatial domain.',
+                'unwrap': 'Unwrap data to 0 to 360 degree spatial domain.',
+                None: 'No wrapping action applied.'}
+        return msgs[self.value]
 
 
 class TimeRange(base.IterableParameter, base.AbstractParameter):
@@ -1258,4 +1305,3 @@ class VectorWrap(base.BooleanParameter):
     default = True
     meta_true = 'Geographic coordinates wrapped from -180 to 180 degrees longitude.'
     meta_false = 'Geographic coordinates match the target dataset coordinate wrapping and may be in the range 0 to 360.'
-
