@@ -5,6 +5,7 @@ from warnings import warn
 
 import netCDF4 as nc
 import numpy as np
+from netCDF4._netCDF4 import MFDataset, MFTime
 
 from ocgis import messages, TemporalDimension
 from ocgis.api.request.driver.base import AbstractDriver
@@ -26,6 +27,14 @@ class NcTemporalDimension(TemporalDimension, NcVectorDimension):
     def __init__(self, *args, **kwargs):
         TemporalDimension.__init__(self, *args, **kwargs)
 
+    def _get_variable_from_dataset_(self, dataset, variable_name):
+        base_variable = super(NcTemporalDimension, self)._get_variable_from_dataset_(dataset, variable_name)
+        if isinstance(dataset, MFDataset):
+            ret = MFTime(base_variable)
+        else:
+            ret = base_variable
+        return ret
+
 
 class DriverNetcdf(AbstractDriver):
     extensions = ('.*\.nc', 'http.*')
@@ -49,7 +58,7 @@ class DriverNetcdf(AbstractDriver):
     def open(self):
         try:
             ret = nc.Dataset(self.rd.uri, 'r')
-        except (TypeError, RuntimeError):
+        except (TypeError, RuntimeError, IOError):
             try:
                 ret = nc.MFDataset(self.rd.uri)
             except KeyError as e:
@@ -197,11 +206,20 @@ class DriverNetcdf(AbstractDriver):
                     ref_variable = {'axis': ref_axis, 'name': ref_axis['dimension'], 'attrs': {}}
 
             # Realization axes may not have an associated variable.
-            if k != 'realization'and len(ref_variable['dimensions']) > 1:
+            if k != 'realization' and len(ref_variable['dimensions']) > 1:
                 return ref_variable
 
             # Extract the data length to use when creating the source index arrays.
-            length = source_metadata['dimensions'][ref_axis['dimension']]['len']
+            try:
+                length = source_metadata['dimensions'][ref_axis['dimension']]['len']
+                is_scalar = False
+            except KeyError:
+                # Scalar level dimensions have no length.
+                if axis_value == 'Z' and ref_axis['dimension'] is None:
+                    length = 1
+                    is_scalar = True
+                else:
+                    raise
             src_idx = np.arange(0, length, dtype=np.int32)
 
             # Get the target data type for the dimension.
@@ -217,13 +235,20 @@ class DriverNetcdf(AbstractDriver):
             # Get the dimension's name.
             name = ref_variable['axis']['dimension']
             # Get if the dimension is unlimited.
-            unlimited = source_metadata['dimensions'][name]['isunlimited']
+            try:
+                unlimited = source_metadata['dimensions'][name]['isunlimited']
+            except KeyError:
+                if is_scalar:
+                    # Scalar level dimensions do not care about being unlimited.
+                    unlimited = False
+                else:
+                    raise
 
             # Assemble keyword arguments for the dimension.
             kwds = dict(name_uid=v['name_uid'], src_idx=src_idx, request_dataset=self.rd, meta=ref_variable,
                         axis=axis_value, name_value=ref_variable.get('name'), dtype=dtype,
                         attrs=ref_variable['attrs'].copy(), name=name, name_bounds=ref_variable['axis'].get('bounds'),
-                        unlimited=unlimited)
+                        unlimited=unlimited, is_scalar=is_scalar)
 
             # There may be additional parameters for each dimension.
             if v['adds'] is not None:
@@ -409,6 +434,15 @@ def get_dimension_map(variable, metadata):
             # variable name may differ from the dimension name
             mp[axis].update({'pos': dims.index(dim)})
 
+    # Do a quick loop over the variables to search for scalar level dimensions.
+    if mp['Z'] is None:
+        for variable_name, variable_meta in metadata['variables'].items():
+            attrs = variable_meta.get('attrs')
+            for attr_name, attr_value in attrs.items():
+                if attr_name == 'axis' and attr_value == 'Z':
+                    mp['Z'] = {'variable': variable_name, 'dimension': None, 'pos': None}
+                    break
+
     # look for bounds variables
     # bounds_names = set(constants.name_bounds)
     for key, value in mp.iteritems():
@@ -440,7 +474,7 @@ def get_dimension_map(variable, metadata):
 
         # the bounds variable was found, but the variable is not actually present in the output file
         if bounds_var not in metadata['variables']:
-            msg = 'Bounds listed for variable "{0}" but the destination bounds variable "{1}" does not exist.'.\
+            msg = 'Bounds listed for variable "{0}" but the destination bounds variable "{1}" does not exist.'. \
                 format(var['name'], bounds_var)
             ocgis_lh(msg, logger='nc.driver', level=logging.WARNING)
             bounds_var = None
