@@ -9,6 +9,7 @@ from ocgis.api.collection import SpatialCollection
 from ocgis.calc.base import AbstractMultivariateFunction, AbstractKeyedOutputFunction
 from ocgis.calc.engine import OcgCalculationEngine
 from ocgis.calc.eval_function import MultivariateEvalFunction
+from ocgis.constants import WrappedState, WrapAction
 from ocgis.exc import EmptyData, ExtentError, MaskedDataError, EmptySubsetError, VariableInCollectionError, \
     BoundsAlreadyAvailableError
 from ocgis.interface.base.crs import CFWGS84, CFRotatedPole, WrappableCoordinateReferenceSystem
@@ -16,9 +17,10 @@ from ocgis.interface.base.dimension.spatial import SpatialGeometryPolygonDimensi
 from ocgis.interface.base.field import Field
 from ocgis.util.helpers import get_default_or_apply
 from ocgis.util.logging_ocgis import ocgis_lh, ProgressOcgOperations
+from ocgis.util.spatial.wrap import CoordinateArrayWrapper
 
 
-class SubsetOperation(object):
+class OperationsEngine(object):
     """
     :param :class:~`ocgis.OcgOperations` ops:
     :param bool request_base_size_only: If ``True``, return field objects following
@@ -227,6 +229,18 @@ class SubsetOperation(object):
                             msg = 'Bounds/corners already on object. Ignoring "interpolate_spatial_bounds".'
                             ocgis_lh(msg=msg, logger=self._subset_log, level=logging.WARNING)
 
+                    # Wrap or unwrap the data if the coordinate system permits.
+                    _update_wrapping_(self, field_object)
+
+                    # Ensure coordinate are ordered in ascending order if requested. Note this will remove
+                    # bounds/corners.
+                    if self.ops.spatial_reorder:
+                        if self.ops.aggregate:
+                            msg = 'Spatial reordering not applicable for spatial aggregations. Reordering not executed.'
+                            ocgis_lh(msg=msg, level=logging.WARN, logger=self._subset_log)
+                        else:
+                            _update_longitude_order_(self, field_object)
+
                     field[ii] = field_object
 
             # update the spatial abstraction to match the operations value. sfield will be none if the operation returns
@@ -271,7 +285,7 @@ class SubsetOperation(object):
         else:
             itr = [None] if self.ops.geom is None else self.ops.geom
         for coll in self._process_geometries_(itr, field, headers, value_keys, alias):
-            yield (coll)
+            yield coll
 
     def _get_initialized_collection_(self, field, headers, value_keys):
         """
@@ -365,7 +379,7 @@ class SubsetOperation(object):
         :raises: AssertionError, ExtentError
         """
 
-        assert (subset_sdim is not None)
+        assert subset_sdim is not None
 
         subset_geom = subset_sdim.single.geom
 
@@ -393,8 +407,8 @@ class SubsetOperation(object):
             self._geom_unique_store.append(subset_geom)
 
         # unwrap the data if it is geographic and 360
-        if field.spatial.wrapped_state == WrappableCoordinateReferenceSystem._flag_unwrapped:
-            if subset_sdim.wrapped_state == WrappableCoordinateReferenceSystem._flag_wrapped:
+        if field.spatial.wrapped_state == WrappedState.UNWRAPPED:
+            if subset_sdim.wrapped_state == WrappedState.WRAPPED:
                 ocgis_lh('unwrapping selection geometry', self._subset_log, alias=alias, ugid=subset_ugid,
                          level=logging.DEBUG)
                 subset_sdim.unwrap()
@@ -405,7 +419,8 @@ class SubsetOperation(object):
         try:
             if self.ops.spatial_operation == 'intersects':
                 sfield = field.get_intersects(subset_geom, use_spatial_index=env.USE_SPATIAL_INDEX,
-                                              select_nearest=self.ops.select_nearest)
+                                              select_nearest=self.ops.select_nearest,
+                                              optimized_bbox_subset=self.ops.optimized_bbox_subset)
             elif self.ops.spatial_operation == 'clip':
                 sfield = field.get_clip(subset_geom, use_spatial_index=env.USE_SPATIAL_INDEX,
                                         select_nearest=self.ops.select_nearest)
@@ -417,13 +432,14 @@ class SubsetOperation(object):
                          level=logging.WARN)
                 sfield = None
             else:
-                msg = ' This typically means the selection geometry falls outside the spatial domain of the target dataset.'
+                msg = ' This typically means the selection geometry falls outside the spatial domain of the target ' \
+                      'dataset.'
                 msg = str(e) + msg
                 ocgis_lh(exc=ExtentError(message=msg), alias=alias, logger=self._subset_log)
 
-        # if the subset geometry is unwrapped and the vector wrap option is true, wrap the subset geometry.
+        # If the subset geometry is unwrapped and the vector wrap option is true, wrap the subset geometry.
         if self.ops.vector_wrap:
-            if subset_sdim.wrapped_state == WrappableCoordinateReferenceSystem._flag_unwrapped:
+            if subset_sdim.wrapped_state == WrappedState.UNWRAPPED:
                 subset_sdim.wrap()
 
         return sfield
@@ -592,8 +608,8 @@ class SubsetOperation(object):
 
                     # wrap the returned data.
                     if not env.OPTIMIZE_FOR_CALC:
-                        if sfield is not None and sfield.spatial.wrapped_state == WrappableCoordinateReferenceSystem._flag_unwrapped:
-                            if self.ops.output_format != 'nc' and self.ops.vector_wrap:
+                        if sfield is not None and sfield.spatial.wrapped_state == WrappedState.UNWRAPPED:
+                            if self.ops.output_format in constants.VECTOR_OUTPUT_FORMATS and self.ops.vector_wrap:
                                 ocgis_lh('wrapping output geometries', self._subset_log, alias=alias, ugid=subset_ugid,
                                          level=logging.DEBUG)
                                 # deepcopy the spatial dimension before wrapping as wrapping will modify the spatial
@@ -627,3 +643,82 @@ class SubsetOperation(object):
             coll.add_field(sfield, ugeom=subset_sdim, name=name)
 
             yield coll
+
+
+def _update_wrapping_(obj, field_object):
+    """
+    Update the wrapped state of the incoming field object. This only affects fields with wrappable coordinate systems.
+
+    :param obj: :class:`ocgis.api.subset.OperationsEngine`
+    :param field_object: :class:`ocgis.Field`
+    """
+    if obj.ops.spatial_wrapping is not None:
+        if isinstance(field_object.crs, WrappableCoordinateReferenceSystem):
+            as_enum = obj.ops._get_object_('spatial_wrapping').as_enum
+            if field_object.spatial.wrapped_state != as_enum:
+                if as_enum == WrapAction.WRAP:
+                    field_object.spatial.wrap()
+                else:
+                    field_object.spatial.unwrap()
+
+
+def _update_longitude_order_(obj, field):
+    """
+    :param obj: The operations interpreter object.
+    :type obj: :class:`ocgis.api.subset.OperationsEngine`
+    :param field: The field object to reorder.
+    :type field: :class:`ocgis.Field`
+    """
+
+    # Reordering only applies when the data is wrapped. Unwrapped reordering is not supported. Raise a warning and
+    # exit the method.
+    wrapped_state = WrappableCoordinateReferenceSystem.get_wrapped_state(field.spatial)
+    if wrapped_state != WrappedState.WRAPPED:
+        msg = 'Reordering may only be performed on wrapped coordinates. Wrapped state is: {}'.format(wrapped_state)
+        ocgis_lh(msg=msg, logger=obj._subset_log, level=logging.WARN)
+        return
+
+    grid = field.spatial.grid
+    # Case without a one-dimensional grid representation.
+    if grid.col is None:
+        w = CoordinateArrayWrapper()
+        # Reference the column coordinates from the grid coordinates array.
+        imap = w.reorder(grid.value[1])
+        # Only the first row of remap coordinates is used for the reorder.
+        imap = imap[0, :].flatten()
+        # Rearrange the source indices on the grid if they are present.
+        if hasattr(grid, '_src_idx') and grid._src_idx is not None:
+            grid._src_idx['col'][:] = grid._src_idx['col'][:, imap]
+        # Remove the reference to any source dataset.
+        grid._request_dataset = None
+    # Case for one-dimensional vector coordinates.
+    else:
+        col = grid.col
+        w = CoordinateArrayWrapper()
+        # Reorder expects a two-dimensional coordinate array.
+        imap = w.reorder(col.value.reshape(1, -1))
+        # Reorder also returns a two-dimensional array. Flatten this for indexing into the variable array.
+        imap = imap.flatten()
+        # Reorder source indices to make sure they are appropriately loaded from file!
+        if hasattr(col, '_src_idx') and col._src_idx is not None:
+            col._src_idx[:] = col._src_idx[imap]
+        # Remove any bounds for the reorder. Also unlink the source data to make sure we don't load again from source.
+        if col.bounds is not None:
+            col._request_dataset = None
+            col.bounds = None
+            grid.row.bounds = None
+            grid.row._request_dataset = None
+        # Force the grid to reload from the updated coordinates.
+        grid._value = None
+
+    # No corners. We are moving to a point abstraction.
+    grid._corners = None
+    # Force geometries to reload as the underlying coordinates may have changed.
+    field.spatial._geom = None
+
+    # Reorder any variable values.
+    for variable in field.variables.values():
+        value = variable._value
+        # Do not load data from source. The source indices should be reordered.
+        if value is not None:
+            value[:] = value[:, :, :, :, imap]
