@@ -4,6 +4,7 @@ from contextlib import contextmanager
 from copy import copy, deepcopy
 
 import fiona
+import netcdftime
 import numpy as np
 from shapely.geometry import mapping
 from shapely.geometry.multipoint import MultiPoint
@@ -111,7 +112,7 @@ class Field(Attributes):
     @name.setter
     def name(self, value):
         self._name = value
-    
+
     @property
     def shape(self):
         """
@@ -125,7 +126,7 @@ class Field(Attributes):
         shape_spatial = get_default_or_apply(self.spatial, lambda x: x.shape, (1, 1))
         ret = (shape_realization, shape_temporal, shape_level, shape_spatial[0], shape_spatial[1])
         return ret
-    
+
     @property
     def shape_as_dict(self):
         """
@@ -178,11 +179,11 @@ class Field(Attributes):
         slc_field[pos] = slc
         ret = self[slc_field]
         return ret
-    
+
     def get_clip(self, polygon, use_spatial_index=True, select_nearest=False):
-        return(self._get_spatial_operation_('get_clip', polygon, use_spatial_index=use_spatial_index,
-                                            select_nearest=select_nearest))
-    
+        return (self._get_spatial_operation_('get_clip', polygon, use_spatial_index=use_spatial_index,
+                                             select_nearest=select_nearest))
+
     @staticmethod
     def get_fiona_dict(field, arch):
         """
@@ -206,7 +207,11 @@ class Field(Attributes):
         fproperties = OrderedDict()
         fconvert = {}
         for k, v in arch.iteritems():
-            ftype = AbstractFionaConverter.get_field_type(type(v))
+            if isinstance(v, netcdftime._netcdftime.datetime):
+                type_v = netcdftime._netcdftime.datetime
+            else:
+                type_v = type(v)
+            ftype = AbstractFionaConverter.get_field_type(type_v)
             fproperties[k] = 'int' if ftype is None else ftype
             if ftype == 'str':
                 fconvert[k] = str
@@ -223,9 +228,10 @@ class Field(Attributes):
         ret['fconvert'] = fconvert
         return ret
 
-    def get_intersects(self, polygon, use_spatial_index=True, select_nearest=False):
-        return(self._get_spatial_operation_('get_intersects', polygon, use_spatial_index=use_spatial_index,
-                                            select_nearest=select_nearest))
+    def get_intersects(self, polygon, use_spatial_index=True, select_nearest=False, optimized_bbox_subset=False):
+        return (self._get_spatial_operation_('get_intersects', polygon, use_spatial_index=use_spatial_index,
+                                             select_nearest=select_nearest,
+                                             optimized_bbox_subset=optimized_bbox_subset))
 
     def get_iter(self, add_masked_value=True, value_keys=None, melted=True, use_upper_keys=False, headers=None,
                  ugeom=None):
@@ -559,7 +565,7 @@ class Field(Attributes):
         try:
             with name_scope(self.level, 'level', 'Z'):
                 self.level.write_netcdf(dataset, unlimited_to_fixedsize=unlimited_to_fixedsize, **kwargs)
-                if self.level is not None:
+                if self.level is not None and not self.level.is_scalar:
                     value_dimensions.append(self.level.name)
         except AttributeError:
             if self.level is not None:
@@ -612,11 +618,12 @@ class Field(Attributes):
 
         self.write_attributes_to_netcdf_object(dataset)
 
-    def _get_spatial_operation_(self, attr, polygon, use_spatial_index=True, select_nearest=False):
+    def _get_spatial_operation_(self, attr, polygon, use_spatial_index=True, select_nearest=False,
+                                optimized_bbox_subset=False):
         ref = getattr(self.spatial, attr)
         ret = copy(self)
         ret.spatial, slc = ref(polygon, return_indices=True, use_spatial_index=use_spatial_index,
-                               select_nearest=select_nearest)
+                               select_nearest=select_nearest, optimized_bbox_subset=optimized_bbox_subset)
         slc = [slice(None), slice(None), slice(None)] + list(slc)
         ret.variables = self.variables.get_sliced_variables(slc)
 
@@ -640,7 +647,7 @@ class Field(Attributes):
 
         yld = {'did': self.uid, 'variable': variable.name, 'alias': variable.alias, 'vid': variable.uid}
         return yld
-                    
+
     def _set_default_names_uids_(self):
 
         def _set_(dim, name, name_uid):
@@ -657,7 +664,6 @@ class Field(Attributes):
 
 
 class DerivedField(Field):
-    
     def _get_variable_iter_yield_(self, variable):
         yld = {'cid': variable.uid, 'calc_key': variable.name, 'calc_alias': variable.alias}
 
