@@ -9,15 +9,21 @@ import numpy as np
 from numpy import dtype
 
 import ocgis
+from ocgis import Field
 from ocgis import constants
 from ocgis import env
 from ocgis.api.operations import OcgOperations
 from ocgis.api.parms import definition
-from ocgis.api.parms.definition import RegridOptions, OutputFormat
+from ocgis.api.parms.definition import RegridOptions, OutputFormat, SpatialWrapping
 from ocgis.api.request.base import RequestDataset
+from ocgis.constants import WrappedState
 from ocgis.exc import DefinitionValidationError, DimensionNotFound, RequestValidationError
-from ocgis.interface.base.crs import CFWGS84
+from ocgis.interface.base.crs import CFWGS84, Spherical, CoordinateReferenceSystem
+from ocgis.interface.base.dimension.base import VectorDimension
+from ocgis.interface.base.dimension.spatial import SpatialGridDimension, SpatialDimension
+from ocgis.interface.base.variable import Variable
 from ocgis.test.base import TestBase, attr
+from ocgis.test.test_simple.test_dependencies import create_mftime_nc_files
 from ocgis.util.geom_cabinet import GeomCabinetIterator, GeomCabinet
 from ocgis.util.helpers import make_poly
 
@@ -26,7 +32,6 @@ class TestOcgOperations(TestBase):
     def setUp(self):
         TestBase.setUp(self)
 
-        # data may need to be pulled from remote repository
         rds = [self.test_data.get_rd('cancm4_tasmin_2001'), self.test_data.get_rd('cancm4_tasmax_2011'),
                self.test_data.get_rd('cancm4_tas')]
 
@@ -74,12 +79,30 @@ class TestOcgOperations(TestBase):
         self.assertTrue(str(ret).startswith('OcgOperations'))
         self.assertGreater(len(ret), 1000)
 
+    @attr('data')
+    def test_system_scalar_level_dimension(self):
+        """Test scalar level dimensions are not dropped in netCDF output."""
+
+        rd = self.test_data.get_rd('cancm4_tas')
+        desired_height_metadata = rd.source_metadata['variables']['height']
+        ops = OcgOperations(dataset=rd, output_format='nc', snippet=True)
+        ret = ops.execute()
+
+        rd_out = RequestDataset(uri=ret)
+        actual = rd_out.source_metadata['variables']['height']
+
+        # Not worried about order of attributes.
+        desired_height_metadata['attrs'] = dict(desired_height_metadata['attrs'])
+        actual['attrs'] = dict(actual['attrs'])
+
+        self.assertDictEqual(actual, desired_height_metadata)
+
     @attr('data')
     def test_get_base_request_size(self):
         rd = self.test_data.get_rd('cancm4_tas')
         ops = OcgOperations(dataset=rd)
         size = ops.get_base_request_size()
-        self.assertEqual(size, {'variables': {'tas': {'level': {'kb': 0.0, 'shape': None, 'dtype': None},
+        self.assertEqual(size, {'variables': {'tas': {'level': {'kb': 0.0078125, 'shape': (1,), 'dtype': None},
                                                       'temporal': {'kb': 28.515625, 'shape': (3650,),
                                                                    'dtype': dtype('float64')},
                                                       'value': {'kb': 116800.0, 'shape': (1, 3650, 1, 64, 128),
@@ -87,7 +110,7 @@ class TestOcgOperations(TestBase):
                                                       'realization': {'kb': 0.0, 'shape': None, 'dtype': None},
                                                       'col': {'kb': 1.0, 'shape': (128,), 'dtype': dtype('float64')},
                                                       'row': {'kb': 0.5, 'shape': (64,), 'dtype': dtype('float64')}}},
-                                'total': 116830.015625})
+                                'total': 116830.0234375})
 
         with self.assertRaises(DefinitionValidationError):
             OcgOperations(dataset=rd, regrid_destination=rd).get_base_request_size()
@@ -106,7 +129,7 @@ class TestOcgOperations(TestBase):
                                                'realization': {'kb': 0.0, 'shape': None, 'dtype': None},
                                                'col': {'kb': 1.046875, 'shape': (134,), 'dtype': dtype('float64')},
                                                'row': {'kb': 0.8515625, 'shape': (109,), 'dtype': dtype('float64')}},
-                                        'tas': {'level': {'kb': 0.0, 'shape': None, 'dtype': None},
+                                        'tas': {'level': {'kb': 0.0078125, 'shape': (1,), 'dtype': None},
                                                 'temporal': {'kb': 28.515625, 'shape': (3650,),
                                                              'dtype': dtype('float64')},
                                                 'value': {'kb': 116800.0, 'shape': (1, 3650, 1, 64, 128),
@@ -114,7 +137,7 @@ class TestOcgOperations(TestBase):
                                                 'realization': {'kb': 0.0, 'shape': None, 'dtype': None},
                                                 'col': {'kb': 1.0, 'shape': (128,), 'dtype': dtype('float64')},
                                                 'row': {'kb': 0.5, 'shape': (64,), 'dtype': dtype('float64')}}},
-                          'total': 1783969.9140625}, size)
+                          'total': 1783969.921875}, size)
 
     @attr('data')
     def test_get_base_request_size_multifile_with_geom(self):
@@ -133,7 +156,7 @@ class TestOcgOperations(TestBase):
                                                              'dtype': dtype('float64')},
                                                      'row': {'kb': 0.1328125, 'shape': (17,),
                                                              'dtype': dtype('float64')}},
-                                              'tas': {'level': {'kb': 0.0, 'shape': None, 'dtype': None},
+                                              'tas': {'level': {'kb': 0.0078125, 'shape': (1,), 'dtype': None},
                                                       'temporal': {'kb': 28.515625, 'shape': (3650,),
                                                                    'dtype': dtype('float64')},
                                                       'value': {'kb': 171.09375, 'shape': (1, 3650, 1, 4, 3),
@@ -142,7 +165,7 @@ class TestOcgOperations(TestBase):
                                                       'col': {'kb': 0.0234375, 'shape': (3,),
                                                               'dtype': dtype('float64')},
                                                       'row': {'kb': 0.03125, 'shape': (4,),
-                                                              'dtype': dtype('float64')}}}, 'total': 21769.5078125})
+                                                              'dtype': dtype('float64')}}}, 'total': 21769.515625})
 
     @attr('data')
     def test_get_base_request_size_test_data(self):
@@ -171,7 +194,7 @@ class TestOcgOperations(TestBase):
         rd = self.test_data.get_rd('cancm4_tas')
         ops = OcgOperations(dataset=rd, geom='state_boundaries', select_ugid=[23])
         size = ops.get_base_request_size()
-        self.assertEqual(size, {'variables': {'tas': {'level': {'kb': 0.0, 'shape': None, 'dtype': None},
+        self.assertEqual(size, {'variables': {'tas': {'level': {'kb': 0.0078125, 'shape': (1,), 'dtype': None},
                                                       'temporal': {'kb': 28.515625, 'shape': (3650,),
                                                                    'dtype': dtype('float64')},
                                                       'value': {'kb': 171.09375, 'shape': (1, 3650, 1, 4, 3),
@@ -180,7 +203,7 @@ class TestOcgOperations(TestBase):
                                                       'col': {'kb': 0.0234375, 'shape': (3,),
                                                               'dtype': dtype('float64')},
                                                       'row': {'kb': 0.03125, 'shape': (4,),
-                                                              'dtype': dtype('float64')}}}, 'total': 199.6640625})
+                                                              'dtype': dtype('float64')}}}, 'total': 199.671875})
 
     @attr('data')
     def test_get_meta(self):
@@ -320,8 +343,6 @@ class TestOcgOperations(TestBase):
         def callback(perc, msg, append=app):
             append.append((perc, msg))
 
-        # print(perc,msg)
-
         rd = self.test_data.get_rd('cancm4_tas')
         rd2 = self.test_data.get_rd('cancm4_tasmax_2011')
         dataset = [rd, rd2]
@@ -584,6 +605,40 @@ class TestOcgOperations(TestBase):
         field = ret[1]['slp']
         self.assertEqual(field.shape, (1, 365, 1, 18, 143))
 
+    @attr('data')
+    def test_keyword_spatial_reorder(self):
+        rd = self.test_data.get_rd('cancm4_tas')
+
+        field_2d = rd.get()[0, 0, 0, :, :]
+        field_2d.spatial.grid.value
+        field_2d.spatial.grid.corners
+        field_2d.variables['tas'].value
+        field_2d.spatial.grid.row = None
+        field_2d.spatial.grid.col = None
+        self.assertIsNone(field_2d.spatial.grid.col)
+
+        kwds = {'dataset': [rd, field_2d], 'geom': [None, [-20, -20, 20, 20]]}
+
+        for ctr, k in enumerate(self.iter_product_keywords(kwds)):
+            # if ctr != 1: continue
+            # print ctr, k
+            original_value = rd.get()[:, 0, :, :, :].variables['tas'].value
+            ops = OcgOperations(dataset=k.dataset, snippet=True, geom=k.geom, spatial_wrapping='wrap',
+                                spatial_reorder=True)
+            ret = ops.execute()
+            field = ret[1]['tas']
+            col_value = field.spatial.grid.value[1]
+            actual_longitude = col_value[:, 0].mean()
+            if k.geom is None:
+                self.assertLess(actual_longitude, -170)
+            else:
+                # Test the subset is applied with reordering.
+                self.assertGreater(actual_longitude, -30)
+                self.assertLess(actual_longitude, 0)
+            # Test the value arrays are not the same following a reorder.
+            with self.assertRaises(AssertionError):
+                self.assertNumpyAll(field.variables['tas'].value, original_value)
+
     @attr('data')
     def test_keyword_time_range(self):
         rd = self.test_data.get_rd('cancm4_tas')
@@ -670,3 +725,68 @@ class TestOcgOperations(TestBase):
         rd = RequestDataset(path)
         with self.assertRaises(DefinitionValidationError):
             OcgOperations(dataset=rd, output_format='csv')
+
+
+class TestOcgOperationsNoData(TestBase):
+    @staticmethod
+    def get_wrap_field(crs=None, unwrapped=True):
+        row = VectorDimension(value=[20, 40])
+        if unwrapped:
+            col_value = [1, 180, 270]
+        else:
+            col_value = [-170, 0, 170]
+        col = VectorDimension(value=col_value)
+        grid = SpatialGridDimension(row=row, col=col)
+        spatial = SpatialDimension(grid=grid, crs=crs)
+        value = np.random.rand(2, 3).reshape(1, 1, 1, 2, 3)
+        var = Variable(name='foo', value=value)
+        field = Field(spatial=spatial, variables=var)
+
+        return field
+
+    def test_system_mftime(self):
+        """Test a multi-file dataset with varying units on the time variables."""
+
+        paths = create_mftime_nc_files(self, with_all_cf=True)
+        rd = RequestDataset(paths)
+        field = rd.get()
+        self.assertIsNone(field.temporal._value)
+
+        desired = [0., 1., 2., 366., 367., 368.]
+        actual = field.temporal.value.tolist()
+        self.assertEqual(actual, desired)
+
+        ops = OcgOperations(dataset=rd, output_format=constants.OUTPUT_FORMAT_NETCDF)
+        ret = ops.execute()
+
+        out_rd = RequestDataset(uri=ret)
+        self.assertEqual(out_rd.get().temporal.value.tolist(), desired)
+
+    def test_keyword_spatial_wrapping(self):
+        keywords = {'spatial_wrapping': list(SpatialWrapping.iter_possible()),
+                    'crs': [None, Spherical(), CoordinateReferenceSystem(epsg=2136)],
+                    'unwrapped': [True, False]}
+        for k in self.iter_product_keywords(keywords):
+            # print(k)
+            field = self.get_wrap_field(crs=k.crs, unwrapped=k.unwrapped)
+
+            ops = OcgOperations(dataset=field, spatial_wrapping=k.spatial_wrapping)
+            ret = ops.execute()
+            actual_field = ret[1]['foo']
+            actual = actual_field.spatial.wrapped_state
+
+            if k.crs != Spherical():
+                desired = None
+            else:
+                p = k.spatial_wrapping
+                if p is None:
+                    if k.unwrapped:
+                        desired = WrappedState.UNWRAPPED
+                    else:
+                        desired = WrappedState.WRAPPED
+                elif p == 'wrap':
+                    desired = WrappedState.WRAPPED
+                else:
+                    desired = WrappedState.UNWRAPPED
+
+            self.assertEqual(actual, desired)
