@@ -581,7 +581,6 @@ class TestGeom(TestBase):
                          'properties': {uid: ugid, 'COUNTRY': coordinate[0]}})
         return geom
 
-    @attr('data')
     def test_init(self):
         geom = make_poly((37.762, 38.222), (-102.281, -101.754))
 
@@ -599,6 +598,7 @@ class TestGeom(TestBase):
         self.assertEqual(g.value[0].geom.polygon.value[0, 0].bounds, (-120.0, 40.0, -110.0, 50.0))
         self.assertEqual(str(g), 'geom=-120.0|40.0|-110.0|50.0')
 
+        ocgis.env.DIR_GEOMCABINET = self.path_bin
         g = Geom('state_boundaries')
         self.assertEqual(str(g), 'geom="state_boundaries"')
 
@@ -631,8 +631,7 @@ class TestGeom(TestBase):
         g = Geom(bbox, geom_uid='ID')
         self.assertEqual(g.geom_uid, 'ID')
 
-        ################################################################################################################
-        # tests for geom_select_sql_where
+        # Tests for geom_select_sql_where.
 
         g = Geom('state_boundaries')
         self.assertIsNone(g.geom_select_sql_where)
@@ -643,7 +642,9 @@ class TestGeom(TestBase):
             g = Geom('state_boundaries', geom_select_sql_where=w)
             self.assertEqual(g.geom_select_sql_where, s)
 
-            ################################################################################################################
+        # Test passing a folder which is not allowed.
+        with self.assertRaises(DefinitionValidationError):
+            Geom(tempfile.gettempdir())
 
     def test_geometry_dictionaries(self):
         """Test geometry dictionaries as input."""
@@ -974,6 +975,16 @@ class TestSpatialOperation(TestBase):
             self.assertEqual(obj.value, a)
 
 
+class TestSpatialWrapping(TestBase):
+    def test_init(self):
+        sw = SpatialWrapping()
+        self.assertIsNone(sw.value)
+        self.assertIsNone(sw.as_enum)
+
+        sw = SpatialWrapping('wrap')
+        self.assertEqual(sw.as_enum, WrapAction.WRAP)
+
+
 class TestTimeRange(TestBase):
     create_dir = False
 
