@@ -1,21 +1,21 @@
-import netCDF4 as nc
 import os
 from copy import deepcopy
 
+import netCDF4 as nc
 import numpy as np
 from shapely.geometry import Point, MultiPoint
 from shapely.geometry.multipolygon import MultiPolygon
 
 import ocgis
 from ocgis import constants
+from ocgis.constants import WrappedState, WrapAction
 from ocgis.exc import SpatialWrappingError
-from ocgis.interface.base.crs import CoordinateReferenceSystem, WGS84,\
+from ocgis.interface.base.crs import CoordinateReferenceSystem, WGS84, \
     CFAlbersEqualArea, CFLambertConformal, CFRotatedPole, CFWGS84, Spherical, WrappableCoordinateReferenceSystem, \
     CFCoordinateReferenceSystem
 from ocgis.interface.base.dimension.base import VectorDimension
-from ocgis.interface.base.dimension.spatial import SpatialGridDimension,\
+from ocgis.interface.base.dimension.spatial import SpatialGridDimension, \
     SpatialDimension
-from ocgis.interface.metadata import NcMetadata
 from ocgis.test.base import TestBase, nc_scope
 from ocgis.test.base import attr
 from ocgis.util.helpers import make_poly
@@ -23,11 +23,11 @@ from ocgis.util.itester import itr_products_keywords
 
 
 class TestCoordinateReferenceSystem(TestBase):
-
     def test_init(self):
-        keywords = dict(value=[None, {'no_defs': True, 'ellps': 'WGS84', 'proj': 'longlat', 'towgs84': '0,0,0,0,0,0,0'}],
-                        epsg=[None, 4326],
-                        proj4=[None, '+proj=longlat +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +no_defs '])
+        keywords = dict(
+            value=[None, {'no_defs': True, 'ellps': 'WGS84', 'proj': 'longlat', 'towgs84': '0,0,0,0,0,0,0'}],
+            epsg=[None, 4326],
+            proj4=[None, '+proj=longlat +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +no_defs '])
 
         prev_crs = None
         for k in itr_products_keywords(keywords):
@@ -39,7 +39,12 @@ class TestCoordinateReferenceSystem(TestBase):
                 else:
                     raise
             self.assertEqual(crs.proj4, '+proj=longlat +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +no_defs ')
-            self.assertDictEqual(crs.value, {'no_defs': True, 'ellps': 'WGS84', 'proj': 'longlat', 'towgs84': '0,0,0,0,0,0,0'})
+            try:
+                self.assertDictEqual(crs.value,
+                                     {'no_defs': True, 'ellps': 'WGS84', 'proj': 'longlat', 'towgs84': '0,0,0,0,0,0,0'})
+            except AssertionError:
+                self.assertDictEqual(crs.value,
+                                     {'no_defs': True, 'datum': 'WGS84', 'proj': 'longlat', 'towgs84': '0,0,0,0,0,0,0'})
             if prev_crs is not None:
                 self.assertEqual(crs, prev_crs)
             prev_crs = deepcopy(crs)
@@ -77,12 +82,19 @@ class TestCoordinateReferenceSystem(TestBase):
                 variable.proj4
 
 
+class TestCFCoordinateReferenceSystem(TestBase):
+    def test_init(self):
+        c = CFLambertConformal(false_easting=0, false_northing=0, latitude_of_projection_origin=38,
+                               standard_parallel=[30., 60.], longitude_of_central_meridian=-77., units='km')
+        self.assertEqual(c.name, c.grid_mapping_name)
+
+
 class TestWrappableCoordinateSystem(TestBase):
     create_dir = False
 
     def test_get_wrap_action(self):
         _w = WrappableCoordinateReferenceSystem
-        possible = [_w._flag_wrapped, _w._flag_unwrapped, _w._flag_unknown, 'foo']
+        possible = [WrappedState.WRAPPED, WrappedState.UNWRAPPED, WrappedState.UNKNOWN, 'foo']
         keywords = dict(state_src=possible,
                         state_dst=possible)
         for k in itr_products_keywords(keywords, as_namedtuple=True):
@@ -91,12 +103,12 @@ class TestWrappableCoordinateSystem(TestBase):
             except ValueError:
                 self.assertTrue(k.state_src == 'foo' or k.state_dst == 'foo')
                 continue
-            if k.state_dst == _w._flag_unknown:
+            if k.state_dst == WrappedState.UNKNOWN:
                 self.assertIsNone(ret)
-            elif k.state_src == _w._flag_unwrapped and k.state_dst == _w._flag_wrapped:
-                self.assertEqual(ret, _w._flag_action_wrap)
-            elif k.state_src == _w._flag_wrapped and k.state_dst == _w._flag_unwrapped:
-                self.assertEqual(ret, _w._flag_action_unwrap)
+            elif k.state_src == WrappedState.UNWRAPPED and k.state_dst == WrappedState.WRAPPED:
+                self.assertEqual(ret, WrapAction.WRAP)
+            elif k.state_src == WrappedState.WRAPPED and k.state_dst == WrappedState.UNWRAPPED:
+                self.assertEqual(ret, WrapAction.UNWRAP)
             else:
                 self.assertIsNone(ret)
 
@@ -104,26 +116,26 @@ class TestWrappableCoordinateSystem(TestBase):
         refv = WrappableCoordinateReferenceSystem
         refm = refv.get_wrapped_state
 
-        ## test grid ##
+        # Test grid wrapping ###########################################################################################
 
         row = VectorDimension(value=[50, 60])
 
         col = VectorDimension(value=[0, 90, 180])
         grid = SpatialGridDimension(row=row, col=col)
         sdim = SpatialDimension(grid=grid)
-        self.assertEqual(refm(sdim), refv._flag_unknown)
+        self.assertEqual(refm(sdim), WrappedState.UNKNOWN)
 
         col = VectorDimension(value=[-170, 0, 30])
         grid = SpatialGridDimension(row=row, col=col)
         sdim = SpatialDimension(grid=grid)
-        self.assertEqual(refm(sdim), refv._flag_wrapped)
+        self.assertEqual(refm(sdim), WrappedState.WRAPPED)
 
         col = VectorDimension(value=[0, 90, 180, 270])
         grid = SpatialGridDimension(row=row, col=col)
         sdim = SpatialDimension(grid=grid)
-        self.assertEqual(refm(sdim), refv._flag_unwrapped)
+        self.assertEqual(refm(sdim), WrappedState.UNWRAPPED)
 
-        ## test geom ##
+        # Test geometry wrapping #######################################################################################
 
         for with_polygon in [True, False]:
             row = VectorDimension(value=[50, 60])
@@ -134,7 +146,7 @@ class TestWrappableCoordinateSystem(TestBase):
             grid = SpatialGridDimension(row=row, col=col)
             sdim = SpatialDimension(grid=grid)
             sdim.grid = None
-            self.assertEqual(refm(sdim), refv._flag_unknown)
+            self.assertEqual(refm(sdim), WrappedState.UNKNOWN)
 
             row = VectorDimension(value=[50, 60])
             col = VectorDimension(value=[160, 170, 180])
@@ -145,9 +157,9 @@ class TestWrappableCoordinateSystem(TestBase):
             sdim = SpatialDimension(grid=grid)
             sdim.grid = None
             if with_polygon:
-                actual = refv._flag_unwrapped
+                actual = WrappedState.UNWRAPPED
             else:
-                actual = refv._flag_unknown
+                actual = WrappedState.UNKNOWN
             self.assertEqual(refm(sdim), actual)
 
             row = VectorDimension(value=[50, 60])
@@ -158,7 +170,7 @@ class TestWrappableCoordinateSystem(TestBase):
             grid = SpatialGridDimension(row=row, col=col)
             sdim = SpatialDimension(grid=grid)
             sdim.grid = None
-            self.assertEqual(refm(sdim), refv._flag_wrapped)
+            self.assertEqual(refm(sdim), WrappedState.WRAPPED)
 
     def test_get_wrapped_state_from_array(self):
 
@@ -167,34 +179,34 @@ class TestWrappableCoordinateSystem(TestBase):
             self.assertEqual(ret, actual_wrapped_state)
 
         arr = np.array([-170])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_wrapped)
+        _run_(arr, WrappedState.WRAPPED)
 
         arr = np.array([270])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_unwrapped)
+        _run_(arr, WrappedState.UNWRAPPED)
 
         arr = np.array([30])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_unknown)
+        _run_(arr, WrappedState.UNKNOWN)
 
         arr = np.array([-180, 0, 30])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_wrapped)
+        _run_(arr, WrappedState.WRAPPED)
 
         arr = np.array([0])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_unknown)
+        _run_(arr, WrappedState.UNKNOWN)
 
         arr = np.array([0, 30, 50])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_unknown)
+        _run_(arr, WrappedState.UNKNOWN)
 
         arr = np.array([0, 30, 50, 181])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_unwrapped)
+        _run_(arr, WrappedState.UNWRAPPED)
 
         arr = np.array([0, 30, 50, 180])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_unknown)
+        _run_(arr, WrappedState.UNKNOWN)
 
         arr = np.array([-180])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_wrapped)
+        _run_(arr, WrappedState.WRAPPED)
 
         arr = np.array([-180, 0, 50])
-        _run_(arr, WrappableCoordinateReferenceSystem._flag_wrapped)
+        _run_(arr, WrappedState.WRAPPED)
 
     def test_get_wrapped_state_from_geometry(self):
         geoms = [Point(-130, 40),
@@ -204,15 +216,14 @@ class TestWrappableCoordinateSystem(TestBase):
 
         for geom in geoms:
             ret = WrappableCoordinateReferenceSystem._get_wrapped_state_from_geometry_(geom)
-            self.assertEqual(ret, WrappableCoordinateReferenceSystem._flag_wrapped)
+            self.assertEqual(ret, WrappedState.WRAPPED)
 
         pt = Point(270, 50)
         ret = WrappableCoordinateReferenceSystem._get_wrapped_state_from_geometry_(pt)
-        self.assertEqual(ret, WrappableCoordinateReferenceSystem._flag_unwrapped)
+        self.assertEqual(ret, WrappedState.UNWRAPPED)
 
 
 class TestSpherical(TestBase):
-
     def test_init(self):
         crs = Spherical()
         self.assertDictEqual(crs.value, {'a': 6370997, 'no_defs': True, 'b': 6370997, 'proj': 'longlat',
@@ -234,14 +245,26 @@ class TestSpherical(TestBase):
         """Test wrapped and unwrapped geometries with a mask ensuring that masked values are wrapped and unwrapped."""
 
         rd = self.test_data.get_rd('cancm4_tas')
-        ops = ocgis.OcgOperations(dataset=rd, geom='state_boundaries', select_ugid=[23])
+
+        ops = ocgis.OcgOperations(dataset=rd, geom='state_boundaries', select_ugid=[23], spatial_wrapping='wrap')
         ret = ops.execute()
         sdim = ret[23]['tas'].spatial
-        actual = np.array([[[34.88252349825162, 34.88252349825162, 34.88252349825162], [37.67309213352349, 37.67309213352349, 37.67309213352349], [40.4636506825932, 40.4636506825932, 40.4636506825932], [43.254197169829105, 43.254197169829105, 43.254197169829105]], [[-120.9375, -118.125, -115.3125], [-120.9375, -118.125, -115.3125], [-120.9375, -118.125, -115.3125], [-120.9375, -118.125, -115.3125]]], dtype=sdim.grid.value.dtype)
+        actual = np.array([[[34.88252349825162, 34.88252349825162, 34.88252349825162],
+                            [37.67309213352349, 37.67309213352349, 37.67309213352349],
+                            [40.4636506825932, 40.4636506825932, 40.4636506825932],
+                            [43.254197169829105, 43.254197169829105, 43.254197169829105]],
+                           [[-120.9375, -118.125, -115.3125], [-120.9375, -118.125, -115.3125],
+                            [-120.9375, -118.125, -115.3125], [-120.9375, -118.125, -115.3125]]],
+                          dtype=sdim.grid.value.dtype)
         self.assertNumpyAll(actual, sdim.grid.value.data)
 
         Spherical().unwrap(sdim)
-        actual = np.array([[[34.88252349825162, 34.88252349825162, 34.88252349825162], [37.67309213352349, 37.67309213352349, 37.67309213352349], [40.4636506825932, 40.4636506825932, 40.4636506825932], [43.254197169829105, 43.254197169829105, 43.254197169829105]], [[239.0625, 241.875, 244.6875], [239.0625, 241.875, 244.6875], [239.0625, 241.875, 244.6875], [239.0625, 241.875, 244.6875]]], dtype=sdim.grid.value.dtype)
+        actual = np.array([[[34.88252349825162, 34.88252349825162, 34.88252349825162],
+                            [37.67309213352349, 37.67309213352349, 37.67309213352349],
+                            [40.4636506825932, 40.4636506825932, 40.4636506825932],
+                            [43.254197169829105, 43.254197169829105, 43.254197169829105]],
+                           [[239.0625, 241.875, 244.6875], [239.0625, 241.875, 244.6875], [239.0625, 241.875, 244.6875],
+                            [239.0625, 241.875, 244.6875]]], dtype=sdim.grid.value.dtype)
         self.assertNumpyAll(actual, sdim.grid.value.data)
 
     def test_wrap_normal(self):
@@ -252,10 +275,10 @@ class TestSpherical(TestBase):
         grid = SpatialGridDimension(row=row, col=col)
         self.assertEqual(grid.resolution, 3.0)
         sdim = SpatialDimension(grid=grid, crs=Spherical())
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_unknown)
+        self.assertEqual(sdim.wrapped_state, WrappedState.UNKNOWN)
         with self.assertRaises(SpatialWrappingError):
             sdim.crs.wrap(sdim)
-    
+
     def test_wrap_360(self):
         """Test wrapping."""
 
@@ -274,7 +297,7 @@ class TestSpherical(TestBase):
         to_test = ([sdim.grid.value, orig_sdim.grid.value], [sdim.grid.corners, orig_sdim.grid.corners])
         for tt in to_test:
             self.assertNumpyAll(*tt)
-    
+
     def test_wrap_360_prime_meridian(self):
         """Test wrapping with bounds interacting with the prime meridian."""
 
@@ -295,20 +318,21 @@ class TestSpherical(TestBase):
 
         # bounds values at the prime meridian of 180.
         orig, sdim = _get_sdim_(178, [176, 180.])
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_unknown)
+        self.assertEqual(sdim.wrapped_state, WrappedState.UNKNOWN)
 
         # bounds values on the other side of the prime meridian
         orig, sdim = _get_sdim_(182, [180, 184])
         sdim.wrap()
-        self.assertIsNone(sdim.grid.col.bounds)
-        self.assertIsNone(sdim.grid.row.bounds)
-        self.assertIsNone(sdim.grid.corners)
+        self.assertNumpyAll(sdim.grid.col.bounds, np.array([[180., -176.]]))
+        self.assertNumpyAll(sdim.grid.row.bounds, np.array([[38., 42.]]))
+        self.assertNumpyAll(sdim.grid.corners, np.ma.array([[[[38.0, 38.0, 42.0, 42.0]]],
+                                                            [[[180.0, -176.0, -176.0, 180.0]]]]))
         self.assertEqual(sdim.geom.polygon.value[0, 0][0].bounds, (-180.0, 38.0, -176.0, 42.0))
         self.assertNumpyAll(np.array(sdim.geom.point.value[0, 0]), np.array([-178., 40.]))
 
         # centroid directly on prime meridian
         orig, sdim = _get_sdim_(180, [178, 182])
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_unknown)
+        self.assertEqual(sdim.wrapped_state, WrappedState.UNKNOWN)
         with self.assertRaises(SpatialWrappingError):
             sdim.wrap()
 
@@ -329,15 +353,14 @@ class TestSpherical(TestBase):
         grid = SpatialGridDimension(row=row, col=col)
         sdim = SpatialDimension(grid=grid, crs=Spherical())
         orig_sdim = deepcopy(sdim)
-        self.assertEqual(orig_sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_unwrapped)
+        self.assertEqual(orig_sdim.wrapped_state, WrappedState.UNWRAPPED)
         sdim.crs.wrap(sdim)
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_wrapped)
+        self.assertEqual(sdim.wrapped_state, WrappedState.WRAPPED)
         sdim.crs.unwrap(sdim)
         self.assertEqual(orig_sdim.geom.polygon.value[0, 0].bounds, sdim.geom.polygon.value[0, 0].bounds)
-            
+
 
 class TestWGS84(TestBase):
-
     def test_init(self):
         self.assertEqual(WGS84(), CoordinateReferenceSystem(epsg=4326))
         self.assertIsInstance(WGS84(), WrappableCoordinateReferenceSystem)
@@ -346,7 +369,6 @@ class TestWGS84(TestBase):
 
 
 class TestCFWGS84(TestBase):
-
     def test_init(self):
         crs = CFWGS84()
         self.assertEqual(crs.map_parameters_values, {})
@@ -355,46 +377,81 @@ class TestCFWGS84(TestBase):
 
 
 class TestCFAlbersEqualArea(TestBase):
-    
     def test_constructor(self):
-        crs = CFAlbersEqualArea(standard_parallel=[29.5,45.5],longitude_of_central_meridian=-96,
-                                latitude_of_projection_origin=37.5,false_easting=0,
+        crs = CFAlbersEqualArea(standard_parallel=[29.5, 45.5], longitude_of_central_meridian=-96,
+                                latitude_of_projection_origin=37.5, false_easting=0,
                                 false_northing=0)
-        self.assertEqual(crs.value,{'lon_0': -96, 'ellps': 'WGS84', 'y_0': 0, 'no_defs': True, 'proj': 'aea', 'x_0': 0, 'units': 'm', 'lat_2': 45.5, 'lat_1': 29.5, 'lat_0': 37.5})
-    
+        self.assertEqual(crs.value, {'lon_0': -96, 'ellps': 'WGS84', 'y_0': 0, 'no_defs': True, 'proj': 'aea', 'x_0': 0,
+                                     'units': 'm', 'lat_2': 45.5, 'lat_1': 29.5, 'lat_0': 37.5})
+
     def test_empty(self):
         with self.assertRaises(KeyError):
             CFAlbersEqualArea()
-            
+
     def test_bad_parms(self):
         with self.assertRaises(KeyError):
-            CFAlbersEqualArea(standard_parallel=[29.5,45.5],longitude_of_central_meridian=-96,
-                              latitude_of_projection_origin=37.5,false_easting=0,
+            CFAlbersEqualArea(standard_parallel=[29.5, 45.5], longitude_of_central_meridian=-96,
+                              latitude_of_projection_origin=37.5, false_easting=0,
                               false_nothing=0)
 
 
 class TestCFLambertConformalConic(TestBase):
-    @attr('data')
+    @property
+    def archetype_minimal_metadata(self):
+        min_meta = {'variables': {'pr': {'name': 'pr',
+                                         'attrs': {'grid_mapping': 'Lambert_Conformal'}
+                                         },
+                                  'Lambert_Conformal': {'name': 'Lambert_Conformal',
+                                                        'attrs': {'false_easting': 3325000.0,
+                                                                  'standard_parallel': [30., 60.],
+                                                                  'false_northing': 2700000.0,
+                                                                  'grid_mapping_name': 'lambert_conformal_conic',
+                                                                  'latitude_of_projection_origin': 47.5,
+                                                                  'longitude_of_central_meridian': -97.0},
+                                                        },
+                                  'xc': {'name': 'xc',
+                                         'attrs': {'units': 'm',
+                                                   'standard_name': 'projection_x_coordinate',
+                                                   'axis': 'X'}
+                                         },
+                                  'yc': {'name': 'yc',
+                                         'attrs': {'units': 'm',
+                                                   'standard_name': 'projection_y_coordinate',
+                                                   'axis': 'Y'}
+                                         }
+                                  }
+                    }
+        return min_meta
+
     def test_load_from_metadata(self):
-        uri = self.test_data.get_uri('narccap_wrfg')
-        ds = nc.Dataset(uri,'r')
-        meta = NcMetadata(ds)
-        crs = CFLambertConformal.load_from_metadata('pr',meta)
+        crs = CFLambertConformal.load_from_metadata('pr', self.archetype_minimal_metadata)
         self.assertEqual(crs.name, 'Lambert_Conformal')
-        self.assertEqual(crs.value,{'lon_0': -97, 'ellps': 'WGS84', 'y_0': 2700000, 'no_defs': True, 'proj': 'lcc', 'x_0': 3325000, 'units': 'm', 'lat_2': 60, 'lat_1': 30, 'lat_0': 47.5})
-        self.assertIsInstance(crs,CFLambertConformal)
-        self.assertEqual(['xc','yc'],[crs.projection_x_coordinate,crs.projection_y_coordinate])
-        self.assertNumpyAll(np.array([ 30.,  60.]),crs.map_parameters_values.pop('standard_parallel'))
-        self.assertEqual(crs.map_parameters_values,{u'latitude_of_projection_origin': 47.5, u'longitude_of_central_meridian': -97.0, u'false_easting': 3325000.0, u'false_northing': 2700000.0, 'units': u'm'})
-        ds.close()
+        self.assertEqual(crs.value, {'lon_0': -97, 'ellps': 'WGS84', 'y_0': 2700000, 'no_defs': True, 'proj': 'lcc',
+                                     'x_0': 3325000, 'units': 'm', 'lat_2': 60, 'lat_1': 30, 'lat_0': 47.5})
+        self.assertIsInstance(crs, CFLambertConformal)
+        self.assertEqual(['xc', 'yc'], [crs.projection_x_coordinate, crs.projection_y_coordinate])
+        self.assertEqual([30., 60.], crs.map_parameters_values.pop('standard_parallel'))
+        self.assertEqual(crs.map_parameters_values,
+                         {'latitude_of_projection_origin': 47.5, 'longitude_of_central_meridian': -97.0,
+                          'false_easting': 3325000.0, 'false_northing': 2700000.0, 'units': 'm'})
+
+    def test_load_from_metadata_no_falses(self):
+        """Test without false easting and false northing in attributes."""
+
+        meta = self.archetype_minimal_metadata
+        to_pop = ['false_easting', 'false_northing']
+        for t in to_pop:
+            meta['variables']['Lambert_Conformal']['attrs'].pop(t)
+
+        crs = CFLambertConformal.load_from_metadata('pr', meta)
+        self.assertIsInstance(crs, CFLambertConformal)
+
+        for proj_parm in ['x_0', 'y_0']:
+            self.assertEqual(crs.value[proj_parm], 0)
 
-    @attr('data')
     def test_write_to_rootgrp(self):
-        uri = self.test_data.get_uri('narccap_wrfg')
-        ds = nc.Dataset(uri,'r')
-        meta = NcMetadata(ds)
-        ds.close()
-        crs = CFLambertConformal.load_from_metadata('pr',meta)
+        meta = self.archetype_minimal_metadata
+        crs = CFLambertConformal.load_from_metadata('pr', meta)
         path = os.path.join(self.current_dir_output, 'foo.nc')
         with nc_scope(path, 'w') as ds:
             variable = crs.write_to_rootgrp(ds)
@@ -404,10 +461,12 @@ class TestCFLambertConformalConic(TestBase):
                 try:
                     self.assertEqual(variable_v, v)
                 except ValueError:
-                    self.assertNumpyAll(variable_v, v)
+                    # Some values come back as NumPy arrays.
+                    self.assertEqual(variable_v.tolist(), v)
 
         with nc_scope(path) as ds:
-            meta2 = NcMetadata(ds)
+            meta2 = {'variables': {'Lambert_Conformal': {'attrs': dict(ds.variables['Lambert_Conformal'].__dict__),
+                                                         'name': 'Lambert_Conformal'}}}
         meta['variables']['Lambert_Conformal'] = meta2['variables']['Lambert_Conformal']
         crs2 = CFLambertConformal.load_from_metadata('pr', meta)
         self.assertEqual(crs, crs2)
@@ -416,13 +475,13 @@ class TestCFLambertConformalConic(TestBase):
         with nc_scope(path2, 'w') as ds:
             crs2.write_to_rootgrp(ds)
 
-        
-class TestCFRotatedPole(TestBase):
 
+class TestCFRotatedPole(TestBase):
     def test_init(self):
         rp = CFRotatedPole(grid_north_pole_latitude=39.25, grid_north_pole_longitude=-162.0)
-        self.assertDictEqual(rp.value, {'lonc': 0, 'ellps': 'WGS84', 'y_0': 0, 'no_defs': True, 'proj': 'omerc', 'x_0': 0,
-                                        'units': 'm', 'alpha': 0, 'k': 1, 'gamma': 0, 'lat_0': 0})
+        self.assertDictEqual(rp.value,
+                             {'lonc': 0, 'ellps': 'WGS84', 'y_0': 0, 'no_defs': True, 'proj': 'omerc', 'x_0': 0,
+                              'units': 'm', 'alpha': 0, 'k': 1, 'gamma': 0, 'lat_0': 0})
 
     @attr('data')
     def test_equal(self):
@@ -511,4 +570,4 @@ class TestCFRotatedPole(TestBase):
             variable = rd.crs.write_to_rootgrp(ds)
             self.assertIsInstance(variable, nc.Variable)
             self.assertEqual(variable.proj4, '')
-            self.assertEqual(variable.proj4_transform, rd.crs._trans_proj)
\ No newline at end of file
+            self.assertEqual(variable.proj4_transform, rd.crs._trans_proj)
