@@ -12,9 +12,10 @@ from shapely.geometry.geo import box
 from shapely.geometry.point import Point
 
 from ocgis import constants, RequestDataset
+from ocgis.constants import WrappedState
 from ocgis.exc import EmptySubsetError, SpatialWrappingError, MultipleElementsFound, BoundsAlreadyAvailableError
 from ocgis.interface.base.crs import CoordinateReferenceSystem, WGS84, CFWGS84, CFRotatedPole, \
-    WrappableCoordinateReferenceSystem, Spherical
+    Spherical
 from ocgis.interface.base.dimension.base import AbstractUidValueDimension
 from ocgis.interface.base.dimension.base import VectorDimension
 from ocgis.interface.base.dimension.spatial import SpatialDimension, SpatialGeometryDimension, \
@@ -805,11 +806,13 @@ class TestSpatialDimension(AbstractTestSpatialDimension):
             sdim.update_crs(to_crs)
 
             if k.with_polygon:
-                self.assertEqual(sdim.geom.polygon.value[2, 2].bounds,
-                                 (130734.585229303, -832179.0855220362, 220974.77455120225, -719113.1357226598))
+                actual = sdim.geom.polygon.value[2, 2].bounds
+                desired = (130734.585229303, -832179.0855220362, 220974.77455120225, -719113.1357226598)
+
             if k.with_point:
-                self.assertEqual(sdim.geom.point.value[2, 2].bounds,
-                                 (175552.29305101855, -775779.6191590576, 175552.29305101855, -775779.6191590576))
+                actual = sdim.geom.point.value[2, 2].bounds
+                desired = (175552.29305101855, -775779.6191590576, 175552.29305101855, -775779.6191590576)
+            self.assertNumpyAllClose(np.array(actual), np.array(desired))
 
     def test_update_crs_grid_combinations(self):
         """Test CRS is updated as expected with different types of grids."""
@@ -858,12 +861,12 @@ class TestSpatialDimension(AbstractTestSpatialDimension):
                 self.assertIsNone(sdim.grid.col)
 
             try:
-                self.assertEqual(sdim.geom.polygon.value[2, 2].bounds,
-                                 (130734.585229303, -832179.0855220362, 220974.77455120225, -719113.1357226598))
+                desired = np.array([130734.585229303, -832179.0855220362, 220974.77455120225, -719113.1357226598])
+                self.assertNumpyAllClose(np.array(sdim.geom.polygon.value[2, 2].bounds), desired)
             except AttributeError:
                 self.assertFalse(k.with_corners)
-            self.assertEqual(sdim.geom.point.value[2, 2].bounds,
-                             (175552.29305101855, -775779.6191590576, 175552.29305101855, -775779.6191590576))
+            desired = np.array([175552.29305101855, -775779.6191590576, 175552.29305101855, -775779.6191590576])
+            self.assertNumpyAllClose(np.array(sdim.geom.point.value[2, 2].bounds), desired)
 
             sdim.update_crs(from_crs)
 
@@ -1079,7 +1082,7 @@ class TestSpatialDimension(AbstractTestSpatialDimension):
         with self.assertRaises(SpatialWrappingError):
             sdim.unwrap()
         sdim.crs = WGS84()
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_wrapped)
+        self.assertEqual(sdim.wrapped_state, WrappedState.WRAPPED)
         sdim.unwrap()
 
         assertUnwrapped(sdim.grid.value)
@@ -1097,7 +1100,7 @@ class TestSpatialDimension(AbstractTestSpatialDimension):
         self.assertNumpyAll(np.array(sdim.geom.polygon.value[2, 2].bounds), np.array(bounds_from_corner))
         self.assertEqual(sdim.geom.polygon.value[2, 2].bounds, (261.5, 37.5, 262.5, 38.5))
         self.assertNumpyAll(np.array(sdim.geom.point.value[2, 2]), np.array([262., 38.]))
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_unwrapped)
+        self.assertEqual(sdim.wrapped_state, WrappedState.UNWRAPPED)
 
     def test_wrap(self):
         """Test wrapping a SpatialDimension"""
@@ -1143,7 +1146,7 @@ class TestSpatialDimension(AbstractTestSpatialDimension):
         self.assertIsNone(sdim.wrapped_state)
 
         sdim = self.get_sdim(crs=CFWGS84())
-        self.assertEqual(sdim.wrapped_state, WrappableCoordinateReferenceSystem._flag_wrapped)
+        self.assertEqual(sdim.wrapped_state, WrappedState.WRAPPED)
 
 
 class TestSpatialGeometryDimension(TestBase):
