@@ -14,7 +14,7 @@ import netCDF4 as nc
 import numpy as np
 from fiona.crs import from_string
 from shapely import wkt
-from shapely.geometry.geo import mapping
+from shapely.geometry.geo import mapping, shape
 from shapely.geometry.point import Point
 from shapely.geometry.polygon import Polygon
 
@@ -26,9 +26,10 @@ from ocgis.api.operations import OcgOperations
 from ocgis.api.parms.definition import OutputFormat
 from ocgis.api.parms.definition import SpatialOperation
 from ocgis.api.request.base import RequestDataset
+from ocgis.constants import WrappedState
 from ocgis.exc import ExtentError, DefinitionValidationError
 from ocgis.interface.base import crs
-from ocgis.interface.base.crs import CoordinateReferenceSystem, WGS84, CFWGS84, WrappableCoordinateReferenceSystem
+from ocgis.interface.base.crs import CoordinateReferenceSystem, WGS84, CFWGS84
 from ocgis.interface.base.field import DerivedMultivariateField
 from ocgis.test import strings
 from ocgis.test.base import TestBase, nc_scope, attr
@@ -235,6 +236,17 @@ class TestSimple(TestSimpleBase):
             with self.assertRaises(ValueError):
                 ops.execute()
 
+    def test_optimized_bbox_subset(self):
+        rd = RequestDataset(**self.get_dataset())
+        geom = [-104.4, 37.6, -102.9, 39.4]
+
+        ops = OcgOperations(dataset=rd, geom=geom, optimized_bbox_subset=True)
+        ret = ops.execute()
+
+        actual = ret[1]['foo'].spatial.grid.value.tolist()
+        desired = [[[38.0, 38.0], [39.0, 39.0]], [[-104.0, -103.0], [-104.0, -103.0]]]
+        self.assertEqual(actual, desired)
+
     def test_operations_abstraction_used_for_subsetting(self):
         ret = self.get_ret(kwds={'abstraction': 'point'})
         ref = ret[1]['foo']
@@ -1339,22 +1351,38 @@ class TestSimple360(TestSimpleBase):
 
         rd = RequestDataset(**self.get_dataset())
         field = rd.get()
-        self.assertEqual(field.spatial.wrapped_state, WrappableCoordinateReferenceSystem._flag_unwrapped)
+        self.assertEqual(field.spatial.wrapped_state, WrappedState.UNWRAPPED)
+
+        # Data should maintain its original wrapped state if the output format is not a vector format.
         ops = OcgOperations(dataset=rd, vector_wrap=True)
         ret = ops.execute()
-        self.assertEqual(ret[1]['foo'].spatial.wrapped_state, WrappableCoordinateReferenceSystem._flag_wrapped)
+        self.assertEqual(ret[1]['foo'].spatial.wrapped_state, WrappedState.UNWRAPPED)
+
+        # If this is a vector output format, the data should be wrapped.
+        for vector_wrap in [True, False]:
+            ops = OcgOperations(dataset=rd, vector_wrap=vector_wrap, output_format=constants.OUTPUT_FORMAT_GEOJSON,
+                                snippet=True, prefix=str(vector_wrap))
+            ret = ops.execute()
+            with fiona.open(ret, driver='GeoJSON') as source:
+                for record in source:
+                    geom = shape(record['geometry'])
+                    arr = np.array(geom[0].exterior)[:, 0]
+                    if vector_wrap:
+                        self.assertTrue(np.all(arr < 0))
+                    else:
+                        self.assertTrue(np.all(arr > 0))
 
     def test_wrap(self):
 
         def _get_longs_(geom):
             ret = np.array([g.centroid.x for g in geom.flat])
-            return (ret)
+            return ret
 
         ret = self.get_ret(kwds={'vector_wrap': False})
         longs_unwrap = _get_longs_(ret[1][self.var].spatial.abstraction_geometry.value)
         self.assertTrue(np.all(longs_unwrap > 180))
 
-        ret = self.get_ret(kwds={'vector_wrap': True})
+        ret = self.get_ret(kwds={'spatial_wrapping': 'wrap'})
         longs_wrap = _get_longs_(ret[1][self.var].spatial.abstraction_geometry.value)
         self.assertTrue(np.all(np.array(longs_wrap) < 180))
 
